/*
 * pama-popup.c: A popup window that can align itself to a widget
 * Part of PulseAudio Mixer Applet
 * Copyright © Vassili Geronimos 2009 <v.geronimos@gmail.com>
 * 
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the Free
 * Software Foundation, either version 3 of the License, or (at your option)
 * any later version.
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
 * more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

 
#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif
#include <glib.h>
#include <glib/gi18n.h>
 
#include "pama-popup.h"

G_DEFINE_TYPE(PamaPopup, pama_popup, GTK_TYPE_WINDOW);

static void pama_popup_class_init(PamaPopupClass *klass)
{
	/* nothing to do here*/
}

static void pama_popup_init(PamaPopup *popup)
{
	/* nothing to do here */
}

void pama_popup_align_with_widget(PamaPopup *popup, GtkWidget *widget, PanelAppletOrient panel_orientation)
{
	GtkRequisition window_req;
	int x, y;
	GdkScreen *screen;
	GdkRectangle monitor;
	int monitor_idx;
	
	gdk_window_get_origin(widget->window, &x, &y);
	x += widget->allocation.x;
	y += widget->allocation.y;
	gtk_widget_size_request(GTK_WIDGET(popup), &window_req);
	
	screen = gtk_window_get_screen(GTK_WINDOW(popup));
	monitor_idx = gdk_screen_get_monitor_at_window(screen, widget->window);
	gdk_screen_get_monitor_geometry(screen, monitor_idx, &monitor);
	
	switch (panel_orientation)
	{
		case PANEL_APPLET_ORIENT_UP:
			y -= window_req.height - 2;
			
			if (x + window_req.width > monitor.x + monitor.width)
				x = monitor.x + monitor.width - window_req.width;
			
			break;
			
		case PANEL_APPLET_ORIENT_DOWN:
			y += widget->allocation.height + 2;
			
			if (x + window_req.width > monitor.x + monitor.width)
				x = monitor.x + monitor.width - window_req.width;
						
			break;
			
		case PANEL_APPLET_ORIENT_RIGHT:
			x += widget->allocation.width + 2;
			
			if (y + window_req.height > monitor.y + monitor.height)
				y = monitor.y + monitor.height - window_req.height;
			
			break;
			
		case PANEL_APPLET_ORIENT_LEFT:
			x -= window_req.width - 2;
			
			if (y + window_req.height > monitor.y + monitor.height)
				y = monitor.y + monitor.height - window_req.height;
			
			break;
	}
	
	gtk_window_move(GTK_WINDOW(popup), x, y);
}
